@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP, NoImplicitPrelude #-}
 module Text.Read.Compat (
    -- * The 'Read' class
    Read(..),
@@ -25,8 +26,8 @@ import Text.Read
 import Text.ParserCombinators.ReadPrec
 import qualified Text.Read.Lex as L
 
-#if !MIN_VERSION_base(4,6,0)
-import Prelude
+#if !(MIN_VERSION_base(4,6,0))
+import Prelude.Compat
 import qualified Text.ParserCombinators.ReadP as P
 
 -- | Parse a string using the 'Read' instance.
